spacr.sequencing — spacr 0.5.0 documentation

# spacr.sequencing

## Module Contents

spacr.sequencing.map_sequences_to_names(csv_file, sequences, rc)

spacr.sequencing.save_df_to_hdf5(df, hdf5_file, key='df', comp_type='zlib', comp_level=5)

spacr.sequencing.save_unique_combinations_to_csv(unique_combinations, csv_file)

spacr.sequencing.save_qc_df_to_csv(qc_df, qc_csv_file)

spacr.sequencing.extract_sequence_and_quality(sequence, quality, start, end)

spacr.sequencing.create_consensus(seq1, qual1, seq2, qual2)

spacr.sequencing.get_consensus_base(bases)

spacr.sequencing.reverse_complement(seq)

spacr.sequencing.process_chunk(chunk_data)

spacr.sequencing.saver_process(save_queue, hdf5_file, save_h5, unique_combinations_csv, qc_csv_file, comp_type, comp_level)

spacr.sequencing.paired_read_chunked_processing(r1_file, r2_file, regex, target_sequence, offset_start, expected_end, column_csv, grna_csv, row_csv, save_h5, comp_type, comp_level, hdf5_file, unique_combinations_csv, qc_csv_file, chunk_size=10000, n_jobs=None, test=False, fill_na=False)

spacr.sequencing.single_read_chunked_processing(r1_file, r2_file, regex, target_sequence, offset_start, expected_end, column_csv, grna_csv, row_csv, save_h5, comp_type, comp_level, hdf5_file, unique_combinations_csv, qc_csv_file, chunk_size=10000, n_jobs=None, test=False, fill_na=False)

spacr.sequencing.generate_barecode_mapping(settings={})

spacr.sequencing.barecodes_reverse_complement(csv_file)

spacr.sequencing.graph_sequencing_stats(settings)